@@ -3,7 +3,10 @@
 
 mod cdcrate;
 mod check;
+mod executable;
+mod githook;
 mod iohelpers;
+mod options;
 mod runner;
 mod subcommands;
 
@@ -12,7 +15,8 @@ pub use crate::iohelpers::{invalid_input, invalid_input_error, IOResult};
 const CMDNAME: &'static str = env!("CARGO_PKG_NAME");
 
 fn main() -> IOResult<()> {
-    use crate::check::Options;
+    use crate::executable::Executable;
+    use crate::options::Options;
 
     crate::cdcrate::change_directory_to_crate_root()?;
     let opts = Options::parse_args();
